Assist class final

A description of a single proposed assist.

Constructors

Assist(AssistKind kind, SourceChange change)
Initializes a newly created assist to have the given kind and change.

Properties

change SourceChange
The change to be made in order to apply the assist.
final
hashCode int
The hash code for this object.
no setterinherited
kind AssistKind
A description of the assist being proposed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compareAssists(Assist a, Assist b) int
Compares two assists by their relevance, then their message.