ChangeBuilder constructor

ChangeBuilder({
  1. AnalysisSession session,
  2. ChangeWorkspace workspace,
  3. String? defaultEol,
})

Initializes a newly created change builder.

If the builder is used to create changes for Dart files, then either a session or a workspace must be provided (but not both).

defaultEol is the default EOL to be used for new files and files that do not have EOLs. Existing files with EOL markers will always have the same EOL in inserted text. If not specified, Platform.lineTerminator will be used.

Implementation

factory ChangeBuilder({
  AnalysisSession session,
  ChangeWorkspace workspace,
  String? defaultEol,
}) = ChangeBuilderImpl;