selectionRange property
SourceRange?
get
selectionRange
Return the range of the selection for the change being built, or null if
there is no selection.
Implementation
SourceRange? get selectionRange;
Return the range of the selection for the change being built, or null if
there is no selection.
SourceRange? get selectionRange;