setSelection abstract method
Set the selection for the change being built to the given position.
Implementation
void setSelection(Position position);
Set the selection for the change being built to the given position.
void setSelection(Position position);