addSimpleLinkedEdit abstract method
void
addSimpleLinkedEdit(
- String groupName,
- String text, {
- LinkedEditSuggestionKind kind,
- List<
String> suggestions,
Add the given text as a linked edit group with the given groupName. If
both a kind and a list of suggestions are provided, they will be added
as suggestions to the group with the given kind.
Throws an ArgumentError if either kind or suggestions are provided
without the other.
Implementation
void addSimpleLinkedEdit(
String groupName,
String text, {
LinkedEditSuggestionKind kind,
List<String> suggestions,
});