selectAll abstract method
void
selectAll(
- void writer()
Set the selection to cover all of the code written by the given writer.
Implementation
void selectAll(void Function() writer);
Set the selection to cover all of the code written by the given writer.
void selectAll(void Function() writer);