addLinkedPosition abstract method
Add the region of text specified by the given range to the linked edit
group with the given groupName. The range is relative to the original
source. This is typically used to include preexisting regions of text in
a group. If the region to be included is part of newly generated text,
then the method EditBuilder.addLinkedEdit should be used instead.
Implementation
void addLinkedPosition(SourceRange range, String groupName);