addSuggestion abstract method
Add the given value as a suggestion with the given kind.
Implementation
void addSuggestion(LinkedEditSuggestionKind kind, String value);
Add the given value as a suggestion with the given kind.
void addSuggestion(LinkedEditSuggestionKind kind, String value);