TokenUtils class

Utilities to work with Tokens.

Constructors

TokenUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getTokens(String s, FeatureSet featureSet) → List<Token>
Returns the tokens of the given Dart source, s.