Plugin class abstract
Constructors
- Plugin()
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginRegistry registry) → FutureOr< void> - Registers analysis rules, quick fixes, and assists.
-
shutDown(
) → FutureOr< void> -
start(
) → FutureOr< void> - Initializes any necessary start-up state that is required for this plugin to run.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited