PluginRegistry class abstract

Constructors

PluginRegistry()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enabled(Map<String, RuleConfig> ruleConfigs) → Iterable<AbstractAnalysisRule>
Returns a list of the enabled rules.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAssist(ProducerGenerator generator) → void
Registers this assist generator with the analyzer's rule registry.
registerFixForRule(DiagnosticCode code, ProducerGenerator generator) → void
Registers this fix generator for the given lint code with the analyzer's rule registry.
registerLintRule(AbstractAnalysisRule rule) → void
Registers this rule with the analyzer's rule registry.
inherited
registerWarningRule(AbstractAnalysisRule rule) → void
Registers this rule with the analyzer's rule registry.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited