enabled abstract method

Iterable<AbstractAnalysisRule> enabled(
  1. Map<String, RuleConfig> ruleConfigs
)
inherited

Returns a list of the enabled rules.

This includes any warning rules, which are enabled by default and are not disabled by the given ruleConfigs, and any lint rules which are explicitly enabled by the given ruleConfigs.

For example: my_rule: true

enables my_rule.

Every key in ruleConfigs should be all lower case.

Implementation

Iterable<AbstractAnalysisRule> enabled(Map<String, RuleConfig> ruleConfigs);