A description of a class of fixes. Instances are intended to hold the
information that is common across a number of fixes and to be shared by those
fixes. For example, if an unnecessary cast is found then one of the suggested
fixes will be to remove the cast. If there are multiple unnecessary casts in
a single file, then there will be multiple fixes, one per occurrence, but
they will all share the same kind.